==> homerun-1.2.0.tar.xz: homerun-1.2.0/fullscreen/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=Homerun
Name[cs]=Homerun
Name[da]=Homerun
Name[de]=Homerun
Name[el]=Homerun
Name[es]=Homerun
Name[fi]=Homerun
Name[fr]=Homerun
Name[gl]=Homerun
Name[hu]=Homerun
Name[nl]=Homerun
Name[pl]=Homerun
Name[pt]=Homerun
Name[pt_BR]=Homerun
Name[ro]=Homerun
Name[ru]=Homerun
Name[sk]=Homerun
Name[sl]=Homerun
Name[sv]=Homerun
Name[tr]=Homerun
Name[uk]=Homerun
Name[x-test]=xxHomerunxx
Name[zh_CN]=Homerun
Comment=An application launcher
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de programas.
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pl]=Program uruchamiający
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Containment

#X-KDE-ParentApp=plasma-desktop
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DefaultSize=290,340
X-Plasma-ContainmentCategories=desktop

==> homerun-1.2.1.tar.xz: homerun-1.2.1/fullscreen/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=Homerun
Name[bs]=Homerun
Name[ca]=Homerun
Name[cs]=Homerun
Name[da]=Homerun
Name[de]=Homerun
Name[el]=Homerun
Name[es]=Homerun
Name[fi]=Homerun
Name[fr]=Homerun
Name[gl]=Homerun
Name[hu]=Homerun
Name[it]=Homerun
Name[ko]=Homerun
Name[nl]=Homerun
Name[pl]=Homerun
Name[pt]=Homerun
Name[pt_BR]=Homerun
Name[ro]=Homerun
Name[ru]=Homerun
Name[sk]=Homerun
Name[sl]=Homerun
Name[sv]=Homerun
Name[tr]=Homerun
Name[uk]=Homerun
Name[x-test]=xxHomerunxx
Name[zh_CN]=Homerun
Comment=An application launcher
Comment[bs]=Pokretač aplikacija
Comment[ca]=Un llançador d'aplicacions
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de programas.
Comment[hu]=Egy alkalmazásindító
Comment[it]=Un avviatore di applicazioni
Comment[ko]=프로그램 실행기
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pl]=Program uruchamiający
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Containment

#X-KDE-ParentApp=plasma-desktop
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DefaultSize=290,340
X-Plasma-ContainmentCategories=desktop
